@@ -1,8 +1,8 @@
 package experimentals;
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use 5.010;
-
+use strict;
 use warnings;
 use feature      ();
 
@@ -81,7 +81,7 @@ experimentals - Experimental features made even easier
 
 =head1 VERSION
 
-This document describes experimentals version 0.015
+This document describes experimentals version 0.016
 
 
 =head1 SYNOPSIS
@@ -218,7 +218,7 @@ whilst under Perl 5.22, it reports:
     old_code.pl line 13:    The bitwise feature
     old_code.pl line 13:    Push on reference
 
-Note that, when <use experimentals -report> is specified
+Note that, when C<use experimentals -report> is specified
 all other non-fatal compile-time warnings are suppressed,
 and the code itself is only compiled, not executed.
 
